# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_nvme_pcie.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
import object_key_pb2 as object__key__pb2
import uuid_pb2 as uuid__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x66rontend_nvme_pcie.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x10object_key.proto\x1a\nuuid.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"}\n\rNVMeSubsystem\x12\x33\n\x04spec\x18\x01 \x01(\x0b\x32%.opi_api.storage.v1.NVMeSubsystemSpec\x12\x37\n\x06status\x18\x02 \x01(\x0b\x32\'.opi_api.storage.v1.NVMeSubsystemStatus\"\x8f\x01\n\x11NVMeSubsystemSpec\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x0b\n\x03nqn\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x14\n\x0cmodel_number\x18\x04 \x01(\t\x12\x16\n\x0emax_namespaces\x18\x05 \x01(\x03\"B\n\x13NVMeSubsystemStatus\x12\x19\n\x11\x66irmware_revision\x18\x01 \x01(\t\x12\x10\n\x08\x66ru_guid\x18\x02 \x01(\x0c\"\x80\x01\n\x0eNVMeController\x12\x34\n\x04spec\x18\x01 \x01(\x0b\x32&.opi_api.storage.v1.NVMeControllerSpec\x12\x38\n\x06status\x18\x02 \x01(\x0b\x32(.opi_api.storage.v1.NVMeControllerStatus\"\x96\x02\n\x12NVMeControllerSpec\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x1a\n\x12nvme_controller_id\x18\x02 \x01(\x05\x12\x32\n\x0csubsystem_id\x18\x03 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x30\n\x07pcie_id\x18\x04 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpoint\x12\x0f\n\x07max_nsq\x18\x05 \x01(\x05\x12\x0f\n\x07max_ncq\x18\x06 \x01(\x05\x12\x0c\n\x04sqes\x18\x07 \x01(\x05\x12\x0c\n\x04\x63qes\x18\x08 \x01(\x05\x12\x16\n\x0emax_namespaces\x18\t \x01(\x05\"&\n\x14NVMeControllerStatus\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\"}\n\rNVMeNamespace\x12\x33\n\x04spec\x18\x01 \x01(\x0b\x32%.opi_api.storage.v1.NVMeNamespaceSpec\x12\x37\n\x06status\x18\x02 \x01(\x0b\x32\'.opi_api.storage.v1.NVMeNamespaceStatus\"\xfa\x01\n\x11NVMeNamespaceSpec\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x32\n\x0csubsystem_id\x18\x02 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x11\n\thost_nsid\x18\x04 \x01(\x05\x12\r\n\x05nguid\x18\x07 \x01(\t\x12\r\n\x05\x65ui64\x18\x08 \x01(\x03\x12%\n\x04uuid\x18\t \x01(\x0b\x32\x17.opi_api.common.v1.Uuid\x12/\n\tvolume_id\x18\n \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"\x9a\x01\n\x13NVMeNamespaceStatus\x12<\n\tpci_state\x18\x01 \x01(\x0e\x32).opi_api.storage.v1.NVMeNamespacePciState\x12\x45\n\x0epci_oper_state\x18\x02 \x01(\x0e\x32-.opi_api.storage.v1.NVMeNamespacePciOperState\"\xb3\x01\n\x1a\x43reateNVMeSubsystemRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\x12?\n\x0fnv_me_subsystem\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.NVMeSubsystemB\x03\xe0\x41\x02\x12\x1a\n\x12nv_me_subsystem_id\x18\x03 \x01(\t\"T\n\x1a\x44\x65leteNVMeSubsystemRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\"\x89\x01\n\x1aUpdateNVMeSubsystemRequest\x12:\n\x0fnv_me_subsystem\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NVMeSubsystem\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"|\n\x19ListNVMeSubsystemsRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n\x1aListNVMeSubsystemsResponse\x12;\n\x10nv_me_subsystems\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NVMeSubsystem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x17GetNVMeSubsystemRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\"O\n\x19NVMeSubsystemStatsRequest\x12\x32\n\x0csubsystem_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"L\n\x1aNVMeSubsystemStatsResponse\x12.\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats\"\xb8\x01\n\x1b\x43reateNVMeControllerRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\x12\x41\n\x10nv_me_controller\x18\x02 \x01(\x0b\x32\".opi_api.storage.v1.NVMeControllerB\x03\xe0\x41\x02\x12\x1b\n\x13nv_me_controller_id\x18\x03 \x01(\t\"V\n\x1b\x44\x65leteNVMeControllerRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\"\x8c\x01\n\x1bUpdateNVMeControllerRequest\x12<\n\x10nv_me_controller\x18\x01 \x01(\x0b\x32\".opi_api.storage.v1.NVMeController\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"~\n\x1aListNVMeControllersRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"u\n\x1bListNVMeControllersResponse\x12=\n\x11nv_me_controllers\x18\x01 \x03(\x0b\x32\".opi_api.storage.v1.NVMeController\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"S\n\x18GetNVMeControllerRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\"F\n\x1aNVMeControllerStatsRequest\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"w\n\x1bNVMeControllerStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats\"\xb3\x01\n\x1a\x43reateNVMeNamespaceRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\x12?\n\x0fnv_me_namespace\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.NVMeNamespaceB\x03\xe0\x41\x02\x12\x1a\n\x12nv_me_namespace_id\x18\x03 \x01(\t\"T\n\x1a\x44\x65leteNVMeNamespaceRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\"\x89\x01\n\x1aUpdateNVMeNamespaceRequest\x12:\n\x0fnv_me_namespace\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NVMeNamespace\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"|\n\x19ListNVMeNamespacesRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n\x1aListNVMeNamespacesResponse\x12;\n\x10nv_me_namespaces\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NVMeNamespace\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x17GetNVMeNamespaceRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\"O\n\x19NVMeNamespaceStatsRequest\x12\x32\n\x0cnamespace_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"v\n\x1aNVMeNamespaceStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats*\xb6\x01\n\x15NVMeNamespacePciState\x12)\n%NV_ME_NAMESPACE_PCI_STATE_UNSPECIFIED\x10\x00\x12%\n!NVME_NAMESPACE_PCI_STATE_DISABLED\x10\x01\x12$\n NVME_NAMESPACE_PCI_STATE_ENABLED\x10\x02\x12%\n!NVME_NAMESPACE_PCI_STATE_DELETING\x10\x03*\xa0\x01\n\x19NVMeNamespacePciOperState\x12.\n*NV_ME_NAMESPACE_PCI_OPER_STATE_UNSPECIFIED\x10\x00\x12(\n$NVME_NAMESPACE_PCI_OPER_STATE_ONLINE\x10\x01\x12)\n%NVME_NAMESPACE_PCI_OPER_STATE_OFFLINE\x10\x02\x32\xa5\x17\n\x13\x46rontendNvmeService\x12\xc6\x01\n\x13\x43reateNVMeSubsystem\x12..opi_api.storage.v1.CreateNVMeSubsystemRequest\x1a!.opi_api.storage.v1.NVMeSubsystem\"\\\x82\xd3\xe4\x93\x02*\"\x17/v1/{parent=subsystems}:\x0fnv_me_subsystem\xda\x41)parent,nv_me_subsystem,nv_me_subsystem_id\x12\x8f\x01\n\x13\x44\x65leteNVMeSubsystem\x12..opi_api.storage.v1.DeleteNVMeSubsystemRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12\xc6\x01\n\x13UpdateNVMeSubsystem\x12..opi_api.storage.v1.UpdateNVMeSubsystemRequest\x1a!.opi_api.storage.v1.NVMeSubsystem\"\\\x82\xd3\xe4\x93\x02\x38\x32%/v1/{nv_me_subsystem.name=subsystems}:\x0fnv_me_subsystem\xda\x41\x1bnv_me_subsystem,update_mask\x12\x9d\x01\n\x12ListNVMeSubsystems\x12-.opi_api.storage.v1.ListNVMeSubsystemsRequest\x1a..opi_api.storage.v1.ListNVMeSubsystemsResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x94\x01\n\x10GetNVMeSubsystem\x12+.opi_api.storage.v1.GetNVMeSubsystemRequest\x1a!.opi_api.storage.v1.NVMeSubsystem\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12u\n\x12NVMeSubsystemStats\x12-.opi_api.storage.v1.NVMeSubsystemStatsRequest\x1a..opi_api.storage.v1.NVMeSubsystemStatsResponse\"\x00\x12\xcc\x01\n\x14\x43reateNVMeController\x12/.opi_api.storage.v1.CreateNVMeControllerRequest\x1a\".opi_api.storage.v1.NVMeController\"_\x82\xd3\xe4\x93\x02+\"\x17/v1/{parent=subsystems}:\x10nv_me_controller\xda\x41+parent,nv_me_controller,nv_me_controller_id\x12\x93\x01\n\x14\x44\x65leteNVMeController\x12/.opi_api.storage.v1.DeleteNVMeControllerRequest\x1a\x16.google.protobuf.Empty\"2\x82\xd3\xe4\x93\x02%*#/v1/{name=controllers}/{controller}\xda\x41\x04name\x12\xcc\x01\n\x14UpdateNVMeController\x12/.opi_api.storage.v1.UpdateNVMeControllerRequest\x1a\".opi_api.storage.v1.NVMeController\"_\x82\xd3\xe4\x93\x02:2&/v1/{nv_me_controller.name=subsystems}:\x10nv_me_controller\xda\x41\x1cnv_me_controller,update_mask\x12\xa0\x01\n\x13ListNVMeControllers\x12..opi_api.storage.v1.ListNVMeControllersRequest\x1a/.opi_api.storage.v1.ListNVMeControllersResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x98\x01\n\x11GetNVMeController\x12,.opi_api.storage.v1.GetNVMeControllerRequest\x1a\".opi_api.storage.v1.NVMeController\"1\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=subsystems}/{controller}\xda\x41\x04name\x12x\n\x13NVMeControllerStats\x12..opi_api.storage.v1.NVMeControllerStatsRequest\x1a/.opi_api.storage.v1.NVMeControllerStatsResponse\"\x00\x12\xc6\x01\n\x13\x43reateNVMeNamespace\x12..opi_api.storage.v1.CreateNVMeNamespaceRequest\x1a!.opi_api.storage.v1.NVMeNamespace\"\\\x82\xd3\xe4\x93\x02*\"\x17/v1/{parent=subsystems}:\x0fnv_me_namespace\xda\x41)parent,nv_me_namespace,nv_me_namespace_id\x12\x8f\x01\n\x13\x44\x65leteNVMeNamespace\x12..opi_api.storage.v1.DeleteNVMeNamespaceRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=namespaces}/{namespace}\xda\x41\x04name\x12\xc6\x01\n\x13UpdateNVMeNamespace\x12..opi_api.storage.v1.UpdateNVMeNamespaceRequest\x1a!.opi_api.storage.v1.NVMeNamespace\"\\\x82\xd3\xe4\x93\x02\x38\x32%/v1/{nv_me_namespace.name=subsystems}:\x0fnv_me_namespace\xda\x41\x1bnv_me_namespace,update_mask\x12\x9d\x01\n\x12ListNVMeNamespaces\x12-.opi_api.storage.v1.ListNVMeNamespacesRequest\x1a..opi_api.storage.v1.ListNVMeNamespacesResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x94\x01\n\x10GetNVMeNamespace\x12+.opi_api.storage.v1.GetNVMeNamespaceRequest\x1a!.opi_api.storage.v1.NVMeNamespace\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{namespace}\xda\x41\x04name\x12u\n\x12NVMeNamespaceStats\x12-.opi_api.storage.v1.NVMeNamespaceStatsRequest\x1a..opi_api.storage.v1.NVMeNamespaceStatsResponse\"\x00\x42\x64\n\x12opi_api.storage.v1B\x15\x46rontendNvmePcieProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_NVMENAMESPACEPCISTATE = DESCRIPTOR.enum_types_by_name['NVMeNamespacePciState']
NVMeNamespacePciState = enum_type_wrapper.EnumTypeWrapper(_NVMENAMESPACEPCISTATE)
_NVMENAMESPACEPCIOPERSTATE = DESCRIPTOR.enum_types_by_name['NVMeNamespacePciOperState']
NVMeNamespacePciOperState = enum_type_wrapper.EnumTypeWrapper(_NVMENAMESPACEPCIOPERSTATE)
NV_ME_NAMESPACE_PCI_STATE_UNSPECIFIED = 0
NVME_NAMESPACE_PCI_STATE_DISABLED = 1
NVME_NAMESPACE_PCI_STATE_ENABLED = 2
NVME_NAMESPACE_PCI_STATE_DELETING = 3
NV_ME_NAMESPACE_PCI_OPER_STATE_UNSPECIFIED = 0
NVME_NAMESPACE_PCI_OPER_STATE_ONLINE = 1
NVME_NAMESPACE_PCI_OPER_STATE_OFFLINE = 2


_NVMESUBSYSTEM = DESCRIPTOR.message_types_by_name['NVMeSubsystem']
_NVMESUBSYSTEMSPEC = DESCRIPTOR.message_types_by_name['NVMeSubsystemSpec']
_NVMESUBSYSTEMSTATUS = DESCRIPTOR.message_types_by_name['NVMeSubsystemStatus']
_NVMECONTROLLER = DESCRIPTOR.message_types_by_name['NVMeController']
_NVMECONTROLLERSPEC = DESCRIPTOR.message_types_by_name['NVMeControllerSpec']
_NVMECONTROLLERSTATUS = DESCRIPTOR.message_types_by_name['NVMeControllerStatus']
_NVMENAMESPACE = DESCRIPTOR.message_types_by_name['NVMeNamespace']
_NVMENAMESPACESPEC = DESCRIPTOR.message_types_by_name['NVMeNamespaceSpec']
_NVMENAMESPACESTATUS = DESCRIPTOR.message_types_by_name['NVMeNamespaceStatus']
_CREATENVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMeSubsystemRequest']
_DELETENVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMeSubsystemRequest']
_UPDATENVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMeSubsystemRequest']
_LISTNVMESUBSYSTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListNVMeSubsystemsRequest']
_LISTNVMESUBSYSTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMeSubsystemsResponse']
_GETNVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['GetNVMeSubsystemRequest']
_NVMESUBSYSTEMSTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMeSubsystemStatsRequest']
_NVMESUBSYSTEMSTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMeSubsystemStatsResponse']
_CREATENVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMeControllerRequest']
_DELETENVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMeControllerRequest']
_UPDATENVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMeControllerRequest']
_LISTNVMECONTROLLERSREQUEST = DESCRIPTOR.message_types_by_name['ListNVMeControllersRequest']
_LISTNVMECONTROLLERSRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMeControllersResponse']
_GETNVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['GetNVMeControllerRequest']
_NVMECONTROLLERSTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMeControllerStatsRequest']
_NVMECONTROLLERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMeControllerStatsResponse']
_CREATENVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMeNamespaceRequest']
_DELETENVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMeNamespaceRequest']
_UPDATENVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMeNamespaceRequest']
_LISTNVMENAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['ListNVMeNamespacesRequest']
_LISTNVMENAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMeNamespacesResponse']
_GETNVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetNVMeNamespaceRequest']
_NVMENAMESPACESTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMeNamespaceStatsRequest']
_NVMENAMESPACESTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMeNamespaceStatsResponse']
NVMeSubsystem = _reflection.GeneratedProtocolMessageType('NVMeSubsystem', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEM,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystem)
  })
_sym_db.RegisterMessage(NVMeSubsystem)

NVMeSubsystemSpec = _reflection.GeneratedProtocolMessageType('NVMeSubsystemSpec', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSPEC,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemSpec)
  })
_sym_db.RegisterMessage(NVMeSubsystemSpec)

NVMeSubsystemStatus = _reflection.GeneratedProtocolMessageType('NVMeSubsystemStatus', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSTATUS,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemStatus)
  })
_sym_db.RegisterMessage(NVMeSubsystemStatus)

NVMeController = _reflection.GeneratedProtocolMessageType('NVMeController', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLER,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeController)
  })
_sym_db.RegisterMessage(NVMeController)

NVMeControllerSpec = _reflection.GeneratedProtocolMessageType('NVMeControllerSpec', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSPEC,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerSpec)
  })
_sym_db.RegisterMessage(NVMeControllerSpec)

NVMeControllerStatus = _reflection.GeneratedProtocolMessageType('NVMeControllerStatus', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSTATUS,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerStatus)
  })
_sym_db.RegisterMessage(NVMeControllerStatus)

NVMeNamespace = _reflection.GeneratedProtocolMessageType('NVMeNamespace', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespace)
  })
_sym_db.RegisterMessage(NVMeNamespace)

NVMeNamespaceSpec = _reflection.GeneratedProtocolMessageType('NVMeNamespaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESPEC,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceSpec)
  })
_sym_db.RegisterMessage(NVMeNamespaceSpec)

NVMeNamespaceStatus = _reflection.GeneratedProtocolMessageType('NVMeNamespaceStatus', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESTATUS,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceStatus)
  })
_sym_db.RegisterMessage(NVMeNamespaceStatus)

CreateNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('CreateNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(CreateNVMeSubsystemRequest)

DeleteNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(DeleteNVMeSubsystemRequest)

UpdateNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(UpdateNVMeSubsystemRequest)

ListNVMeSubsystemsRequest = _reflection.GeneratedProtocolMessageType('ListNVMeSubsystemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMESUBSYSTEMSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeSubsystemsRequest)
  })
_sym_db.RegisterMessage(ListNVMeSubsystemsRequest)

ListNVMeSubsystemsResponse = _reflection.GeneratedProtocolMessageType('ListNVMeSubsystemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMESUBSYSTEMSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeSubsystemsResponse)
  })
_sym_db.RegisterMessage(ListNVMeSubsystemsResponse)

GetNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('GetNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(GetNVMeSubsystemRequest)

NVMeSubsystemStatsRequest = _reflection.GeneratedProtocolMessageType('NVMeSubsystemStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSTATSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemStatsRequest)
  })
_sym_db.RegisterMessage(NVMeSubsystemStatsRequest)

NVMeSubsystemStatsResponse = _reflection.GeneratedProtocolMessageType('NVMeSubsystemStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSTATSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemStatsResponse)
  })
_sym_db.RegisterMessage(NVMeSubsystemStatsResponse)

CreateNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('CreateNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMeControllerRequest)
  })
_sym_db.RegisterMessage(CreateNVMeControllerRequest)

DeleteNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMeControllerRequest)
  })
_sym_db.RegisterMessage(DeleteNVMeControllerRequest)

UpdateNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMeControllerRequest)
  })
_sym_db.RegisterMessage(UpdateNVMeControllerRequest)

ListNVMeControllersRequest = _reflection.GeneratedProtocolMessageType('ListNVMeControllersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMECONTROLLERSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeControllersRequest)
  })
_sym_db.RegisterMessage(ListNVMeControllersRequest)

ListNVMeControllersResponse = _reflection.GeneratedProtocolMessageType('ListNVMeControllersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMECONTROLLERSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeControllersResponse)
  })
_sym_db.RegisterMessage(ListNVMeControllersResponse)

GetNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('GetNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMeControllerRequest)
  })
_sym_db.RegisterMessage(GetNVMeControllerRequest)

NVMeControllerStatsRequest = _reflection.GeneratedProtocolMessageType('NVMeControllerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSTATSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerStatsRequest)
  })
_sym_db.RegisterMessage(NVMeControllerStatsRequest)

NVMeControllerStatsResponse = _reflection.GeneratedProtocolMessageType('NVMeControllerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSTATSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerStatsResponse)
  })
_sym_db.RegisterMessage(NVMeControllerStatsResponse)

CreateNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('CreateNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(CreateNVMeNamespaceRequest)

DeleteNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(DeleteNVMeNamespaceRequest)

UpdateNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(UpdateNVMeNamespaceRequest)

ListNVMeNamespacesRequest = _reflection.GeneratedProtocolMessageType('ListNVMeNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMENAMESPACESREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeNamespacesRequest)
  })
_sym_db.RegisterMessage(ListNVMeNamespacesRequest)

ListNVMeNamespacesResponse = _reflection.GeneratedProtocolMessageType('ListNVMeNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMENAMESPACESRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeNamespacesResponse)
  })
_sym_db.RegisterMessage(ListNVMeNamespacesResponse)

GetNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(GetNVMeNamespaceRequest)

NVMeNamespaceStatsRequest = _reflection.GeneratedProtocolMessageType('NVMeNamespaceStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESTATSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceStatsRequest)
  })
_sym_db.RegisterMessage(NVMeNamespaceStatsRequest)

NVMeNamespaceStatsResponse = _reflection.GeneratedProtocolMessageType('NVMeNamespaceStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESTATSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceStatsResponse)
  })
_sym_db.RegisterMessage(NVMeNamespaceStatsResponse)

_FRONTENDNVMESERVICE = DESCRIPTOR.services_by_name['FrontendNvmeService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\025FrontendNvmePcieProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['parent']._options = None
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['nv_me_subsystem']._options = None
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['nv_me_subsystem']._serialized_options = b'\340A\002'
  _DELETENVMESUBSYSTEMREQUEST.fields_by_name['name']._options = None
  _DELETENVMESUBSYSTEMREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _LISTNVMESUBSYSTEMSREQUEST.fields_by_name['parent']._options = None
  _LISTNVMESUBSYSTEMSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _GETNVMESUBSYSTEMREQUEST.fields_by_name['name']._options = None
  _GETNVMESUBSYSTEMREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _CREATENVMECONTROLLERREQUEST.fields_by_name['parent']._options = None
  _CREATENVMECONTROLLERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _CREATENVMECONTROLLERREQUEST.fields_by_name['nv_me_controller']._options = None
  _CREATENVMECONTROLLERREQUEST.fields_by_name['nv_me_controller']._serialized_options = b'\340A\002'
  _DELETENVMECONTROLLERREQUEST.fields_by_name['name']._options = None
  _DELETENVMECONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _LISTNVMECONTROLLERSREQUEST.fields_by_name['parent']._options = None
  _LISTNVMECONTROLLERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _GETNVMECONTROLLERREQUEST.fields_by_name['name']._options = None
  _GETNVMECONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _CREATENVMENAMESPACEREQUEST.fields_by_name['parent']._options = None
  _CREATENVMENAMESPACEREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _CREATENVMENAMESPACEREQUEST.fields_by_name['nv_me_namespace']._options = None
  _CREATENVMENAMESPACEREQUEST.fields_by_name['nv_me_namespace']._serialized_options = b'\340A\002'
  _DELETENVMENAMESPACEREQUEST.fields_by_name['name']._options = None
  _DELETENVMENAMESPACEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _LISTNVMENAMESPACESREQUEST.fields_by_name['parent']._options = None
  _LISTNVMENAMESPACESREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _GETNVMENAMESPACEREQUEST.fields_by_name['name']._options = None
  _GETNVMENAMESPACEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeSubsystem']._serialized_options = b'\202\323\344\223\002*\"\027/v1/{parent=subsystems}:\017nv_me_subsystem\332A)parent,nv_me_subsystem,nv_me_subsystem_id'
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeSubsystem']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeSubsystem']._serialized_options = b'\202\323\344\223\00282%/v1/{nv_me_subsystem.name=subsystems}:\017nv_me_subsystem\332A\033nv_me_subsystem,update_mask'
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeSubsystems']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeSubsystems']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeSubsystem']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeController']._serialized_options = b'\202\323\344\223\002+\"\027/v1/{parent=subsystems}:\020nv_me_controller\332A+parent,nv_me_controller,nv_me_controller_id'
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeController']._serialized_options = b'\202\323\344\223\002%*#/v1/{name=controllers}/{controller}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeController']._serialized_options = b'\202\323\344\223\002:2&/v1/{nv_me_controller.name=subsystems}:\020nv_me_controller\332A\034nv_me_controller,update_mask'
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeControllers']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeControllers']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeController']._serialized_options = b'\202\323\344\223\002$\022\"/v1/{name=subsystems}/{controller}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeNamespace']._serialized_options = b'\202\323\344\223\002*\"\027/v1/{parent=subsystems}:\017nv_me_namespace\332A)parent,nv_me_namespace,nv_me_namespace_id'
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeNamespace']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=namespaces}/{namespace}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeNamespace']._serialized_options = b'\202\323\344\223\00282%/v1/{nv_me_namespace.name=subsystems}:\017nv_me_namespace\332A\033nv_me_namespace,update_mask'
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeNamespaces']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeNamespaces']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeNamespace']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{namespace}\332A\004name'
  _NVMENAMESPACEPCISTATE._serialized_start=4373
  _NVMENAMESPACEPCISTATE._serialized_end=4555
  _NVMENAMESPACEPCIOPERSTATE._serialized_start=4558
  _NVMENAMESPACEPCIOPERSTATE._serialized_end=4718
  _NVMESUBSYSTEM._serialized_start=273
  _NVMESUBSYSTEM._serialized_end=398
  _NVMESUBSYSTEMSPEC._serialized_start=401
  _NVMESUBSYSTEMSPEC._serialized_end=544
  _NVMESUBSYSTEMSTATUS._serialized_start=546
  _NVMESUBSYSTEMSTATUS._serialized_end=612
  _NVMECONTROLLER._serialized_start=615
  _NVMECONTROLLER._serialized_end=743
  _NVMECONTROLLERSPEC._serialized_start=746
  _NVMECONTROLLERSPEC._serialized_end=1024
  _NVMECONTROLLERSTATUS._serialized_start=1026
  _NVMECONTROLLERSTATUS._serialized_end=1064
  _NVMENAMESPACE._serialized_start=1066
  _NVMENAMESPACE._serialized_end=1191
  _NVMENAMESPACESPEC._serialized_start=1194
  _NVMENAMESPACESPEC._serialized_end=1444
  _NVMENAMESPACESTATUS._serialized_start=1447
  _NVMENAMESPACESTATUS._serialized_end=1601
  _CREATENVMESUBSYSTEMREQUEST._serialized_start=1604
  _CREATENVMESUBSYSTEMREQUEST._serialized_end=1783
  _DELETENVMESUBSYSTEMREQUEST._serialized_start=1785
  _DELETENVMESUBSYSTEMREQUEST._serialized_end=1869
  _UPDATENVMESUBSYSTEMREQUEST._serialized_start=1872
  _UPDATENVMESUBSYSTEMREQUEST._serialized_end=2009
  _LISTNVMESUBSYSTEMSREQUEST._serialized_start=2011
  _LISTNVMESUBSYSTEMSREQUEST._serialized_end=2135
  _LISTNVMESUBSYSTEMSRESPONSE._serialized_start=2137
  _LISTNVMESUBSYSTEMSRESPONSE._serialized_end=2251
  _GETNVMESUBSYSTEMREQUEST._serialized_start=2253
  _GETNVMESUBSYSTEMREQUEST._serialized_end=2334
  _NVMESUBSYSTEMSTATSREQUEST._serialized_start=2336
  _NVMESUBSYSTEMSTATSREQUEST._serialized_end=2415
  _NVMESUBSYSTEMSTATSRESPONSE._serialized_start=2417
  _NVMESUBSYSTEMSTATSRESPONSE._serialized_end=2493
  _CREATENVMECONTROLLERREQUEST._serialized_start=2496
  _CREATENVMECONTROLLERREQUEST._serialized_end=2680
  _DELETENVMECONTROLLERREQUEST._serialized_start=2682
  _DELETENVMECONTROLLERREQUEST._serialized_end=2768
  _UPDATENVMECONTROLLERREQUEST._serialized_start=2771
  _UPDATENVMECONTROLLERREQUEST._serialized_end=2911
  _LISTNVMECONTROLLERSREQUEST._serialized_start=2913
  _LISTNVMECONTROLLERSREQUEST._serialized_end=3039
  _LISTNVMECONTROLLERSRESPONSE._serialized_start=3041
  _LISTNVMECONTROLLERSRESPONSE._serialized_end=3158
  _GETNVMECONTROLLERREQUEST._serialized_start=3160
  _GETNVMECONTROLLERREQUEST._serialized_end=3243
  _NVMECONTROLLERSTATSREQUEST._serialized_start=3245
  _NVMECONTROLLERSTATSREQUEST._serialized_end=3315
  _NVMECONTROLLERSTATSRESPONSE._serialized_start=3317
  _NVMECONTROLLERSTATSRESPONSE._serialized_end=3436
  _CREATENVMENAMESPACEREQUEST._serialized_start=3439
  _CREATENVMENAMESPACEREQUEST._serialized_end=3618
  _DELETENVMENAMESPACEREQUEST._serialized_start=3620
  _DELETENVMENAMESPACEREQUEST._serialized_end=3704
  _UPDATENVMENAMESPACEREQUEST._serialized_start=3707
  _UPDATENVMENAMESPACEREQUEST._serialized_end=3844
  _LISTNVMENAMESPACESREQUEST._serialized_start=3846
  _LISTNVMENAMESPACESREQUEST._serialized_end=3970
  _LISTNVMENAMESPACESRESPONSE._serialized_start=3972
  _LISTNVMENAMESPACESRESPONSE._serialized_end=4086
  _GETNVMENAMESPACEREQUEST._serialized_start=4088
  _GETNVMENAMESPACEREQUEST._serialized_end=4169
  _NVMENAMESPACESTATSREQUEST._serialized_start=4171
  _NVMENAMESPACESTATSREQUEST._serialized_end=4250
  _NVMENAMESPACESTATSRESPONSE._serialized_start=4252
  _NVMENAMESPACESTATSRESPONSE._serialized_end=4370
  _FRONTENDNVMESERVICE._serialized_start=4721
  _FRONTENDNVMESERVICE._serialized_end=7702
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import middleend_pb2 as middleend__pb2


class MiddleendServiceStub(object):
    """Middle End (Storage Services) APIs. For example, encryption, compression, raid, QoS, multipath, ...
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEncryptedVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendService/CreateEncryptedVolume',
                request_serializer=middleend__pb2.CreateEncryptedVolumeRequest.SerializeToString,
                response_deserializer=middleend__pb2.EncryptedVolume.FromString,
                )
        self.DeleteEncryptedVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendService/DeleteEncryptedVolume',
                request_serializer=middleend__pb2.DeleteEncryptedVolumeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateEncryptedVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendService/UpdateEncryptedVolume',
                request_serializer=middleend__pb2.UpdateEncryptedVolumeRequest.SerializeToString,
                response_deserializer=middleend__pb2.EncryptedVolume.FromString,
                )
        self.ListEncryptedVolumes = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendService/ListEncryptedVolumes',
                request_serializer=middleend__pb2.ListEncryptedVolumesRequest.SerializeToString,
                response_deserializer=middleend__pb2.ListEncryptedVolumesResponse.FromString,
                )
        self.GetEncryptedVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendService/GetEncryptedVolume',
                request_serializer=middleend__pb2.GetEncryptedVolumeRequest.SerializeToString,
                response_deserializer=middleend__pb2.EncryptedVolume.FromString,
                )
        self.EncryptedVolumeStats = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendService/EncryptedVolumeStats',
                request_serializer=middleend__pb2.EncryptedVolumeStatsRequest.SerializeToString,
                response_deserializer=middleend__pb2.EncryptedVolumeStatsResponse.FromString,
                )


class MiddleendServiceServicer(object):
    """Middle End (Storage Services) APIs. For example, encryption, compression, raid, QoS, multipath, ...
    """

    def CreateEncryptedVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEncryptedVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEncryptedVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEncryptedVolumes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEncryptedVolume(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EncryptedVolumeStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MiddleendServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEncryptedVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEncryptedVolume,
                    request_deserializer=middleend__pb2.CreateEncryptedVolumeRequest.FromString,
                    response_serializer=middleend__pb2.EncryptedVolume.SerializeToString,
            ),
            'DeleteEncryptedVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEncryptedVolume,
                    request_deserializer=middleend__pb2.DeleteEncryptedVolumeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateEncryptedVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEncryptedVolume,
                    request_deserializer=middleend__pb2.UpdateEncryptedVolumeRequest.FromString,
                    response_serializer=middleend__pb2.EncryptedVolume.SerializeToString,
            ),
            'ListEncryptedVolumes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEncryptedVolumes,
                    request_deserializer=middleend__pb2.ListEncryptedVolumesRequest.FromString,
                    response_serializer=middleend__pb2.ListEncryptedVolumesResponse.SerializeToString,
            ),
            'GetEncryptedVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEncryptedVolume,
                    request_deserializer=middleend__pb2.GetEncryptedVolumeRequest.FromString,
                    response_serializer=middleend__pb2.EncryptedVolume.SerializeToString,
            ),
            'EncryptedVolumeStats': grpc.unary_unary_rpc_method_handler(
                    servicer.EncryptedVolumeStats,
                    request_deserializer=middleend__pb2.EncryptedVolumeStatsRequest.FromString,
                    response_serializer=middleend__pb2.EncryptedVolumeStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.MiddleendService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MiddleendService(object):
    """Middle End (Storage Services) APIs. For example, encryption, compression, raid, QoS, multipath, ...
    """

    @staticmethod
    def CreateEncryptedVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendService/CreateEncryptedVolume',
            middleend__pb2.CreateEncryptedVolumeRequest.SerializeToString,
            middleend__pb2.EncryptedVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEncryptedVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendService/DeleteEncryptedVolume',
            middleend__pb2.DeleteEncryptedVolumeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEncryptedVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendService/UpdateEncryptedVolume',
            middleend__pb2.UpdateEncryptedVolumeRequest.SerializeToString,
            middleend__pb2.EncryptedVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEncryptedVolumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendService/ListEncryptedVolumes',
            middleend__pb2.ListEncryptedVolumesRequest.SerializeToString,
            middleend__pb2.ListEncryptedVolumesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEncryptedVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendService/GetEncryptedVolume',
            middleend__pb2.GetEncryptedVolumeRequest.SerializeToString,
            middleend__pb2.EncryptedVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EncryptedVolumeStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendService/EncryptedVolumeStats',
            middleend__pb2.EncryptedVolumeStatsRequest.SerializeToString,
            middleend__pb2.EncryptedVolumeStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_nvme_tcp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import object_key_pb2 as object__key__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x62\x61\x63kend_nvme_tcp.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x10object_key.proto\x1a\x0fopicommon.proto\"\xf1\x02\n\x14NVMfRemoteController\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x35\n\x06trtype\x18\x02 \x01(\x0e\x32%.opi_api.storage.v1.NvmeTransportType\x12\x35\n\x06\x61\x64rfam\x18\x03 \x01(\x0e\x32%.opi_api.storage.v1.NvmeAddressFamily\x12\x0e\n\x06traddr\x18\x04 \x01(\t\x12\x0f\n\x07trsvcid\x18\x05 \x01(\x03\x12\x0e\n\x06subnqn\x18\x06 \x01(\t\x12\r\n\x05hdgst\x18\x07 \x01(\x08\x12\r\n\x05\x64\x64gst\x18\x08 \x01(\x08\x12\x34\n\tmultipath\x18\t \x01(\x0e\x32!.opi_api.storage.v1.NvmeMultipath\x12\x17\n\x0fio_queues_count\x18\n \x01(\x03\x12\x12\n\nqueue_size\x18\x0b \x01(\x03\x12\x0f\n\x07hostnqn\x18\x0c \x01(\t\"\xd8\x01\n!CreateNVMfRemoteControllerRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/NVMfRemoteController\x12N\n\x17nv_mf_remote_controller\x18\x02 \x01(\x0b\x32(.opi_api.storage.v1.NVMfRemoteControllerB\x03\xe0\x41\x02\x12\"\n\x1anv_mf_remote_controller_id\x18\x03 \x01(\t\"b\n!DeleteNVMfRemoteControllerRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/NVMfRemoteController\"\x9f\x01\n!UpdateNVMfRemoteControllerRequest\x12I\n\x17nv_mf_remote_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.NVMfRemoteController\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x8a\x01\n ListNVMfRemoteControllersRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/NVMfRemoteController\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n!ListNVMfRemoteControllersResponse\x12J\n\x18nv_mf_remote_controllers\x18\x01 \x03(\x0b\x32(.opi_api.storage.v1.NVMfRemoteController\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"_\n\x1eGetNVMfRemoteControllerRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/NVMfRemoteController\"L\n NVMfRemoteControllerResetRequest\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"L\n NVMfRemoteControllerStatsRequest\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"S\n!NVMfRemoteControllerStatsResponse\x12.\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats*\xb4\x01\n\x11NvmeTransportType\x12#\n\x1fNVME_TRANSPORT_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11NVME_TRANSPORT_FC\x10\x01\x12\x17\n\x13NVME_TRANSPORT_PCIE\x10\x02\x12\x17\n\x13NVME_TRANSPORT_RDMA\x10\x03\x12\x16\n\x12NVME_TRANSPORT_TCP\x10\x04\x12\x19\n\x15NVME_TRANSPORT_CUSTOM\x10\x05*\xa8\x01\n\x11NvmeAddressFamily\x12#\n\x1fNVME_ADDRESS_FAMILY_UNSPECIFIED\x10\x00\x12\x14\n\x10NVMF_ADRFAM_IPV4\x10\x01\x12\x14\n\x10NVMF_ADRFAM_IPV6\x10\x02\x12\x12\n\x0eNVMF_ADRFAM_IB\x10\x03\x12\x12\n\x0eNVMF_ADRFAM_FC\x10\x04\x12\x1a\n\x16NVMF_ADRFAM_INTRA_HOST\x10\x05*\x86\x01\n\rNvmeMultipath\x12\x1e\n\x1aNVME_MULTIPATH_UNSPECIFIED\x10\x00\x12\x1a\n\x16NVME_MULTIPATH_DISABLE\x10\x01\x12\x1b\n\x17NVME_MULTIPATH_FAILOVER\x10\x02\x12\x1c\n\x18NVME_MULTIPATH_MULTIPATH\x10\x03\x32\x84\n\n\x1bNVMfRemoteControllerService\x12\xf3\x01\n\x1a\x43reateNVMfRemoteController\x12\x35.opi_api.storage.v1.CreateNVMfRemoteControllerRequest\x1a(.opi_api.storage.v1.NVMfRemoteController\"t\x82\xd3\xe4\x93\x02\x32\"\x17/v1/{parent=subsystems}:\x17nv_mf_remote_controller\xda\x41\x39parent,nv_mf_remote_controller,nv_mf_remote_controller_id\x12\x9d\x01\n\x1a\x44\x65leteNVMfRemoteController\x12\x35.opi_api.storage.v1.DeleteNVMfRemoteControllerRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12\xf3\x01\n\x1aUpdateNVMfRemoteController\x12\x35.opi_api.storage.v1.UpdateNVMfRemoteControllerRequest\x1a(.opi_api.storage.v1.NVMfRemoteController\"t\x82\xd3\xe4\x93\x02H2-/v1/{nv_mf_remote_controller.name=subsystems}:\x17nv_mf_remote_controller\xda\x41#nv_mf_remote_controller,update_mask\x12\xb2\x01\n\x19ListNVMfRemoteControllers\x12\x34.opi_api.storage.v1.ListNVMfRemoteControllersRequest\x1a\x35.opi_api.storage.v1.ListNVMfRemoteControllersResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\xa9\x01\n\x17GetNVMfRemoteController\x12\x32.opi_api.storage.v1.GetNVMfRemoteControllerRequest\x1a(.opi_api.storage.v1.NVMfRemoteController\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12k\n\x19NVMfRemoteControllerReset\x12\x34.opi_api.storage.v1.NVMfRemoteControllerResetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x8a\x01\n\x19NVMfRemoteControllerStats\x12\x34.opi_api.storage.v1.NVMfRemoteControllerStatsRequest\x1a\x35.opi_api.storage.v1.NVMfRemoteControllerStatsResponse\"\x00\x42\x62\n\x12opi_api.storage.v1B\x13\x42\x61\x63kendNvmeTcpProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_NVMETRANSPORTTYPE = DESCRIPTOR.enum_types_by_name['NvmeTransportType']
NvmeTransportType = enum_type_wrapper.EnumTypeWrapper(_NVMETRANSPORTTYPE)
_NVMEADDRESSFAMILY = DESCRIPTOR.enum_types_by_name['NvmeAddressFamily']
NvmeAddressFamily = enum_type_wrapper.EnumTypeWrapper(_NVMEADDRESSFAMILY)
_NVMEMULTIPATH = DESCRIPTOR.enum_types_by_name['NvmeMultipath']
NvmeMultipath = enum_type_wrapper.EnumTypeWrapper(_NVMEMULTIPATH)
NVME_TRANSPORT_TYPE_UNSPECIFIED = 0
NVME_TRANSPORT_FC = 1
NVME_TRANSPORT_PCIE = 2
NVME_TRANSPORT_RDMA = 3
NVME_TRANSPORT_TCP = 4
NVME_TRANSPORT_CUSTOM = 5
NVME_ADDRESS_FAMILY_UNSPECIFIED = 0
NVMF_ADRFAM_IPV4 = 1
NVMF_ADRFAM_IPV6 = 2
NVMF_ADRFAM_IB = 3
NVMF_ADRFAM_FC = 4
NVMF_ADRFAM_INTRA_HOST = 5
NVME_MULTIPATH_UNSPECIFIED = 0
NVME_MULTIPATH_DISABLE = 1
NVME_MULTIPATH_FAILOVER = 2
NVME_MULTIPATH_MULTIPATH = 3


_NVMFREMOTECONTROLLER = DESCRIPTOR.message_types_by_name['NVMfRemoteController']
_CREATENVMFREMOTECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMfRemoteControllerRequest']
_DELETENVMFREMOTECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMfRemoteControllerRequest']
_UPDATENVMFREMOTECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMfRemoteControllerRequest']
_LISTNVMFREMOTECONTROLLERSREQUEST = DESCRIPTOR.message_types_by_name['ListNVMfRemoteControllersRequest']
_LISTNVMFREMOTECONTROLLERSRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMfRemoteControllersResponse']
_GETNVMFREMOTECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['GetNVMfRemoteControllerRequest']
_NVMFREMOTECONTROLLERRESETREQUEST = DESCRIPTOR.message_types_by_name['NVMfRemoteControllerResetRequest']
_NVMFREMOTECONTROLLERSTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMfRemoteControllerStatsRequest']
_NVMFREMOTECONTROLLERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMfRemoteControllerStatsResponse']
NVMfRemoteController = _reflection.GeneratedProtocolMessageType('NVMfRemoteController', (_message.Message,), {
  'DESCRIPTOR' : _NVMFREMOTECONTROLLER,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMfRemoteController)
  })
_sym_db.RegisterMessage(NVMfRemoteController)

CreateNVMfRemoteControllerRequest = _reflection.GeneratedProtocolMessageType('CreateNVMfRemoteControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMFREMOTECONTROLLERREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMfRemoteControllerRequest)
  })
_sym_db.RegisterMessage(CreateNVMfRemoteControllerRequest)

DeleteNVMfRemoteControllerRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMfRemoteControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMFREMOTECONTROLLERREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMfRemoteControllerRequest)
  })
_sym_db.RegisterMessage(DeleteNVMfRemoteControllerRequest)

UpdateNVMfRemoteControllerRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMfRemoteControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMFREMOTECONTROLLERREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMfRemoteControllerRequest)
  })
_sym_db.RegisterMessage(UpdateNVMfRemoteControllerRequest)

ListNVMfRemoteControllersRequest = _reflection.GeneratedProtocolMessageType('ListNVMfRemoteControllersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMFREMOTECONTROLLERSREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMfRemoteControllersRequest)
  })
_sym_db.RegisterMessage(ListNVMfRemoteControllersRequest)

ListNVMfRemoteControllersResponse = _reflection.GeneratedProtocolMessageType('ListNVMfRemoteControllersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMFREMOTECONTROLLERSRESPONSE,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMfRemoteControllersResponse)
  })
_sym_db.RegisterMessage(ListNVMfRemoteControllersResponse)

GetNVMfRemoteControllerRequest = _reflection.GeneratedProtocolMessageType('GetNVMfRemoteControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMFREMOTECONTROLLERREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMfRemoteControllerRequest)
  })
_sym_db.RegisterMessage(GetNVMfRemoteControllerRequest)

NVMfRemoteControllerResetRequest = _reflection.GeneratedProtocolMessageType('NVMfRemoteControllerResetRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMFREMOTECONTROLLERRESETREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMfRemoteControllerResetRequest)
  })
_sym_db.RegisterMessage(NVMfRemoteControllerResetRequest)

NVMfRemoteControllerStatsRequest = _reflection.GeneratedProtocolMessageType('NVMfRemoteControllerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMFREMOTECONTROLLERSTATSREQUEST,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMfRemoteControllerStatsRequest)
  })
_sym_db.RegisterMessage(NVMfRemoteControllerStatsRequest)

NVMfRemoteControllerStatsResponse = _reflection.GeneratedProtocolMessageType('NVMfRemoteControllerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMFREMOTECONTROLLERSTATSRESPONSE,
  '__module__' : 'backend_nvme_tcp_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMfRemoteControllerStatsResponse)
  })
_sym_db.RegisterMessage(NVMfRemoteControllerStatsResponse)

_NVMFREMOTECONTROLLERSERVICE = DESCRIPTOR.services_by_name['NVMfRemoteControllerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\023BackendNvmeTcpProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATENVMFREMOTECONTROLLERREQUEST.fields_by_name['parent']._options = None
  _CREATENVMFREMOTECONTROLLERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/NVMfRemoteController'
  _CREATENVMFREMOTECONTROLLERREQUEST.fields_by_name['nv_mf_remote_controller']._options = None
  _CREATENVMFREMOTECONTROLLERREQUEST.fields_by_name['nv_mf_remote_controller']._serialized_options = b'\340A\002'
  _DELETENVMFREMOTECONTROLLERREQUEST.fields_by_name['name']._options = None
  _DELETENVMFREMOTECONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/NVMfRemoteController'
  _LISTNVMFREMOTECONTROLLERSREQUEST.fields_by_name['parent']._options = None
  _LISTNVMFREMOTECONTROLLERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/NVMfRemoteController'
  _GETNVMFREMOTECONTROLLERREQUEST.fields_by_name['name']._options = None
  _GETNVMFREMOTECONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/NVMfRemoteController'
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['CreateNVMfRemoteController']._options = None
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['CreateNVMfRemoteController']._serialized_options = b'\202\323\344\223\0022\"\027/v1/{parent=subsystems}:\027nv_mf_remote_controller\332A9parent,nv_mf_remote_controller,nv_mf_remote_controller_id'
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['DeleteNVMfRemoteController']._options = None
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['DeleteNVMfRemoteController']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['UpdateNVMfRemoteController']._options = None
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['UpdateNVMfRemoteController']._serialized_options = b'\202\323\344\223\002H2-/v1/{nv_mf_remote_controller.name=subsystems}:\027nv_mf_remote_controller\332A#nv_mf_remote_controller,update_mask'
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['ListNVMfRemoteControllers']._options = None
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['ListNVMfRemoteControllers']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['GetNVMfRemoteController']._options = None
  _NVMFREMOTECONTROLLERSERVICE.methods_by_name['GetNVMfRemoteController']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _NVMETRANSPORTTYPE._serialized_start=1731
  _NVMETRANSPORTTYPE._serialized_end=1911
  _NVMEADDRESSFAMILY._serialized_start=1914
  _NVMEADDRESSFAMILY._serialized_end=2082
  _NVMEMULTIPATH._serialized_start=2085
  _NVMEMULTIPATH._serialized_end=2219
  _NVMFREMOTECONTROLLER._serialized_start=260
  _NVMFREMOTECONTROLLER._serialized_end=629
  _CREATENVMFREMOTECONTROLLERREQUEST._serialized_start=632
  _CREATENVMFREMOTECONTROLLERREQUEST._serialized_end=848
  _DELETENVMFREMOTECONTROLLERREQUEST._serialized_start=850
  _DELETENVMFREMOTECONTROLLERREQUEST._serialized_end=948
  _UPDATENVMFREMOTECONTROLLERREQUEST._serialized_start=951
  _UPDATENVMFREMOTECONTROLLERREQUEST._serialized_end=1110
  _LISTNVMFREMOTECONTROLLERSREQUEST._serialized_start=1113
  _LISTNVMFREMOTECONTROLLERSREQUEST._serialized_end=1251
  _LISTNVMFREMOTECONTROLLERSRESPONSE._serialized_start=1254
  _LISTNVMFREMOTECONTROLLERSRESPONSE._serialized_end=1390
  _GETNVMFREMOTECONTROLLERREQUEST._serialized_start=1392
  _GETNVMFREMOTECONTROLLERREQUEST._serialized_end=1487
  _NVMFREMOTECONTROLLERRESETREQUEST._serialized_start=1489
  _NVMFREMOTECONTROLLERRESETREQUEST._serialized_end=1565
  _NVMFREMOTECONTROLLERSTATSREQUEST._serialized_start=1567
  _NVMFREMOTECONTROLLERSTATSREQUEST._serialized_end=1643
  _NVMFREMOTECONTROLLERSTATSRESPONSE._serialized_start=1645
  _NVMFREMOTECONTROLLERSTATSRESPONSE._serialized_end=1728
  _NVMFREMOTECONTROLLERSERVICE._serialized_start=2222
  _NVMFREMOTECONTROLLERSERVICE._serialized_end=3506
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_virtio_scsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
import object_key_pb2 as object__key__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x66rontend_virtio_scsi.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x10object_key.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"N\n\x10VirtioScsiTarget\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x10\n\x08max_luns\x18\x02 \x01(\x05\"r\n\x14VirtioScsiController\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x30\n\x07pcie_id\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpoint\"\x9b\x01\n\rVirtioScsiLun\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12/\n\ttarget_id\x18\x02 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12/\n\tvolume_id\x18\x03 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"\xc2\x01\n\x1d\x43reateVirtioScsiTargetRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTarget\x12\x45\n\x12virtio_scsi_target\x18\x02 \x01(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetB\x03\xe0\x41\x02\x12\x1d\n\x15virtio_scsi_target_id\x18\x03 \x01(\t\"Z\n\x1d\x44\x65leteVirtioScsiTargetRequest\x12\x39\n\x04name\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTarget\"\x92\x01\n\x1dUpdateVirtioScsiTargetRequest\x12@\n\x12virtio_scsi_target\x18\x01 \x01(\x0b\x32$.opi_api.storage.v1.VirtioScsiTarget\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x82\x01\n\x1cListVirtioScsiTargetsRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTarget\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x1dListVirtioScsiTargetsResponse\x12\x41\n\x13virtio_scsi_targets\x18\x01 \x03(\x0b\x32$.opi_api.storage.v1.VirtioScsiTarget\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"W\n\x1aGetVirtioScsiTargetRequest\x12\x39\n\x04name\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTarget\"O\n\x1cVirtioScsiTargetStatsRequest\x12/\n\ttarget_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"y\n\x1dVirtioScsiTargetStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats\"\xd6\x01\n!CreateVirtioScsiControllerRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiController\x12M\n\x16virtio_scsi_controller\x18\x02 \x01(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerB\x03\xe0\x41\x02\x12!\n\x19virtio_scsi_controller_id\x18\x03 \x01(\t\"b\n!DeleteVirtioScsiControllerRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiController\"\x9e\x01\n!UpdateVirtioScsiControllerRequest\x12H\n\x16virtio_scsi_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.VirtioScsiController\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x8a\x01\n ListVirtioScsiControllersRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiController\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x87\x01\n!ListVirtioScsiControllersResponse\x12I\n\x17virtio_scsi_controllers\x18\x01 \x03(\x0b\x32(.opi_api.storage.v1.VirtioScsiController\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"_\n\x1eGetVirtioScsiControllerRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiController\"W\n VirtioScsiControllerStatsRequest\x12\x33\n\rcontroller_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"}\n!VirtioScsiControllerStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats\"\xb3\x01\n\x1a\x43reateVirtioScsiLunRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLun\x12?\n\x0fvirtio_scsi_lun\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunB\x03\xe0\x41\x02\x12\x1a\n\x12virtio_scsi_lun_id\x18\x03 \x01(\t\"T\n\x1a\x44\x65leteVirtioScsiLunRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLun\"\x89\x01\n\x1aUpdateVirtioScsiLunRequest\x12:\n\x0fvirtio_scsi_lun\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.VirtioScsiLun\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"|\n\x19ListVirtioScsiLunsRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLun\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n\x1aListVirtioScsiLunsResponse\x12;\n\x10virtio_scsi_luns\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.VirtioScsiLun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x17GetVirtioScsiLunRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLun\"~\n\x19VirtioScsiLunStatsRequest\x12\x33\n\rcontroller_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12,\n\x06lun_id\x18\x02 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"v\n\x1aVirtioScsiLunStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats2\xa1\x19\n\x19\x46rontendVirtioScsiService\x12\xd8\x01\n\x16\x43reateVirtioScsiTarget\x12\x31.opi_api.storage.v1.CreateVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"e\x82\xd3\xe4\x93\x02-\"\x17/v1/{parent=subsystems}:\x12virtio_scsi_target\xda\x41/parent,virtio_scsi_target,virtio_scsi_target_id\x12\x9c\x01\n\x16\x44\x65leteVirtioScsiTarget\x12\x31.opi_api.storage.v1.DeleteVirtioScsiTargetRequest\x1a\x16.google.protobuf.Empty\"7\x82\xd3\xe4\x93\x02**(/v1/{name=subsystems}/{virtioscsitarget}\xda\x41\x04name\x12\xd8\x01\n\x16UpdateVirtioScsiTarget\x12\x31.opi_api.storage.v1.UpdateVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"e\x82\xd3\xe4\x93\x02>2(/v1/{virtio_scsi_target.name=subsystems}:\x12virtio_scsi_target\xda\x41\x1evirtio_scsi_target,update_mask\x12\xa6\x01\n\x15ListVirtioScsiTargets\x12\x30.opi_api.storage.v1.ListVirtioScsiTargetsRequest\x1a\x31.opi_api.storage.v1.ListVirtioScsiTargetsResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\xa4\x01\n\x13GetVirtioScsiTarget\x12..opi_api.storage.v1.GetVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"7\x82\xd3\xe4\x93\x02*\x12(/v1/{name=subsystems}/{virtioscsitarget}\xda\x41\x04name\x12~\n\x15VirtioScsiTargetStats\x12\x30.opi_api.storage.v1.VirtioScsiTargetStatsRequest\x1a\x31.opi_api.storage.v1.VirtioScsiTargetStatsResponse\"\x00\x12\xf0\x01\n\x1a\x43reateVirtioScsiController\x12\x35.opi_api.storage.v1.CreateVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"q\x82\xd3\xe4\x93\x02\x31\"\x17/v1/{parent=subsystems}:\x16virtio_scsi_controller\xda\x41\x37parent,virtio_scsi_controller,virtio_scsi_controller_id\x12\xa7\x01\n\x1a\x44\x65leteVirtioScsiController\x12\x35.opi_api.storage.v1.DeleteVirtioScsiControllerRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02-*+/v1/{name=virtioscsictrls}/{virtioscsictrl}\xda\x41\x04name\x12\xf0\x01\n\x1aUpdateVirtioScsiController\x12\x35.opi_api.storage.v1.UpdateVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"q\x82\xd3\xe4\x93\x02\x46\x32,/v1/{virtio_scsi_controller.name=subsystems}:\x16virtio_scsi_controller\xda\x41\"virtio_scsi_controller,update_mask\x12\xb2\x01\n\x19ListVirtioScsiControllers\x12\x34.opi_api.storage.v1.ListVirtioScsiControllersRequest\x1a\x35.opi_api.storage.v1.ListVirtioScsiControllersResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\xae\x01\n\x17GetVirtioScsiController\x12\x32.opi_api.storage.v1.GetVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"5\x82\xd3\xe4\x93\x02(\x12&/v1/{name=subsystems}/{virtioscsictrl}\xda\x41\x04name\x12\x8a\x01\n\x19VirtioScsiControllerStats\x12\x34.opi_api.storage.v1.VirtioScsiControllerStatsRequest\x1a\x35.opi_api.storage.v1.VirtioScsiControllerStatsResponse\"\x00\x12\xc6\x01\n\x13\x43reateVirtioScsiLun\x12..opi_api.storage.v1.CreateVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"\\\x82\xd3\xe4\x93\x02*\"\x17/v1/{parent=subsystems}:\x0fvirtio_scsi_lun\xda\x41)parent,virtio_scsi_lun,virtio_scsi_lun_id\x12\x97\x01\n\x13\x44\x65leteVirtioScsiLun\x12..opi_api.storage.v1.DeleteVirtioScsiLunRequest\x1a\x16.google.protobuf.Empty\"8\x82\xd3\xe4\x93\x02+*)/v1/{name=virtioscsiluns}/{virtioscsilun}\xda\x41\x04name\x12\xc6\x01\n\x13UpdateVirtioScsiLun\x12..opi_api.storage.v1.UpdateVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"\\\x82\xd3\xe4\x93\x02\x38\x32%/v1/{virtio_scsi_lun.name=subsystems}:\x0fvirtio_scsi_lun\xda\x41\x1bvirtio_scsi_lun,update_mask\x12\x9d\x01\n\x12ListVirtioScsiLuns\x12-.opi_api.storage.v1.ListVirtioScsiLunsRequest\x1a..opi_api.storage.v1.ListVirtioScsiLunsResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x98\x01\n\x10GetVirtioScsiLun\x12+.opi_api.storage.v1.GetVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"4\x82\xd3\xe4\x93\x02\'\x12%/v1/{name=subsystems}/{virtioscsilun}\xda\x41\x04name\x12u\n\x12VirtioScsiLunStats\x12-.opi_api.storage.v1.VirtioScsiLunStatsRequest\x1a..opi_api.storage.v1.VirtioScsiLunStatsResponse\"\x00\x42\x66\n\x12opi_api.storage.v1B\x17\x46rontendVirtioScsiProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')



_VIRTIOSCSITARGET = DESCRIPTOR.message_types_by_name['VirtioScsiTarget']
_VIRTIOSCSICONTROLLER = DESCRIPTOR.message_types_by_name['VirtioScsiController']
_VIRTIOSCSILUN = DESCRIPTOR.message_types_by_name['VirtioScsiLun']
_CREATEVIRTIOSCSITARGETREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtioScsiTargetRequest']
_DELETEVIRTIOSCSITARGETREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtioScsiTargetRequest']
_UPDATEVIRTIOSCSITARGETREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtioScsiTargetRequest']
_LISTVIRTIOSCSITARGETSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtioScsiTargetsRequest']
_LISTVIRTIOSCSITARGETSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtioScsiTargetsResponse']
_GETVIRTIOSCSITARGETREQUEST = DESCRIPTOR.message_types_by_name['GetVirtioScsiTargetRequest']
_VIRTIOSCSITARGETSTATSREQUEST = DESCRIPTOR.message_types_by_name['VirtioScsiTargetStatsRequest']
_VIRTIOSCSITARGETSTATSRESPONSE = DESCRIPTOR.message_types_by_name['VirtioScsiTargetStatsResponse']
_CREATEVIRTIOSCSICONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtioScsiControllerRequest']
_DELETEVIRTIOSCSICONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtioScsiControllerRequest']
_UPDATEVIRTIOSCSICONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtioScsiControllerRequest']
_LISTVIRTIOSCSICONTROLLERSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtioScsiControllersRequest']
_LISTVIRTIOSCSICONTROLLERSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtioScsiControllersResponse']
_GETVIRTIOSCSICONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['GetVirtioScsiControllerRequest']
_VIRTIOSCSICONTROLLERSTATSREQUEST = DESCRIPTOR.message_types_by_name['VirtioScsiControllerStatsRequest']
_VIRTIOSCSICONTROLLERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['VirtioScsiControllerStatsResponse']
_CREATEVIRTIOSCSILUNREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtioScsiLunRequest']
_DELETEVIRTIOSCSILUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteVirtioScsiLunRequest']
_UPDATEVIRTIOSCSILUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateVirtioScsiLunRequest']
_LISTVIRTIOSCSILUNSREQUEST = DESCRIPTOR.message_types_by_name['ListVirtioScsiLunsRequest']
_LISTVIRTIOSCSILUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListVirtioScsiLunsResponse']
_GETVIRTIOSCSILUNREQUEST = DESCRIPTOR.message_types_by_name['GetVirtioScsiLunRequest']
_VIRTIOSCSILUNSTATSREQUEST = DESCRIPTOR.message_types_by_name['VirtioScsiLunStatsRequest']
_VIRTIOSCSILUNSTATSRESPONSE = DESCRIPTOR.message_types_by_name['VirtioScsiLunStatsResponse']
VirtioScsiTarget = _reflection.GeneratedProtocolMessageType('VirtioScsiTarget', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSITARGET,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiTarget)
  })
_sym_db.RegisterMessage(VirtioScsiTarget)

VirtioScsiController = _reflection.GeneratedProtocolMessageType('VirtioScsiController', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSICONTROLLER,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiController)
  })
_sym_db.RegisterMessage(VirtioScsiController)

VirtioScsiLun = _reflection.GeneratedProtocolMessageType('VirtioScsiLun', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSILUN,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiLun)
  })
_sym_db.RegisterMessage(VirtioScsiLun)

CreateVirtioScsiTargetRequest = _reflection.GeneratedProtocolMessageType('CreateVirtioScsiTargetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTIOSCSITARGETREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateVirtioScsiTargetRequest)
  })
_sym_db.RegisterMessage(CreateVirtioScsiTargetRequest)

DeleteVirtioScsiTargetRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtioScsiTargetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTIOSCSITARGETREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteVirtioScsiTargetRequest)
  })
_sym_db.RegisterMessage(DeleteVirtioScsiTargetRequest)

UpdateVirtioScsiTargetRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtioScsiTargetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTIOSCSITARGETREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateVirtioScsiTargetRequest)
  })
_sym_db.RegisterMessage(UpdateVirtioScsiTargetRequest)

ListVirtioScsiTargetsRequest = _reflection.GeneratedProtocolMessageType('ListVirtioScsiTargetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOSCSITARGETSREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioScsiTargetsRequest)
  })
_sym_db.RegisterMessage(ListVirtioScsiTargetsRequest)

ListVirtioScsiTargetsResponse = _reflection.GeneratedProtocolMessageType('ListVirtioScsiTargetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOSCSITARGETSRESPONSE,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioScsiTargetsResponse)
  })
_sym_db.RegisterMessage(ListVirtioScsiTargetsResponse)

GetVirtioScsiTargetRequest = _reflection.GeneratedProtocolMessageType('GetVirtioScsiTargetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTIOSCSITARGETREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetVirtioScsiTargetRequest)
  })
_sym_db.RegisterMessage(GetVirtioScsiTargetRequest)

VirtioScsiTargetStatsRequest = _reflection.GeneratedProtocolMessageType('VirtioScsiTargetStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSITARGETSTATSREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiTargetStatsRequest)
  })
_sym_db.RegisterMessage(VirtioScsiTargetStatsRequest)

VirtioScsiTargetStatsResponse = _reflection.GeneratedProtocolMessageType('VirtioScsiTargetStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSITARGETSTATSRESPONSE,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiTargetStatsResponse)
  })
_sym_db.RegisterMessage(VirtioScsiTargetStatsResponse)

CreateVirtioScsiControllerRequest = _reflection.GeneratedProtocolMessageType('CreateVirtioScsiControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTIOSCSICONTROLLERREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateVirtioScsiControllerRequest)
  })
_sym_db.RegisterMessage(CreateVirtioScsiControllerRequest)

DeleteVirtioScsiControllerRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtioScsiControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTIOSCSICONTROLLERREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteVirtioScsiControllerRequest)
  })
_sym_db.RegisterMessage(DeleteVirtioScsiControllerRequest)

UpdateVirtioScsiControllerRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtioScsiControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTIOSCSICONTROLLERREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateVirtioScsiControllerRequest)
  })
_sym_db.RegisterMessage(UpdateVirtioScsiControllerRequest)

ListVirtioScsiControllersRequest = _reflection.GeneratedProtocolMessageType('ListVirtioScsiControllersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOSCSICONTROLLERSREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioScsiControllersRequest)
  })
_sym_db.RegisterMessage(ListVirtioScsiControllersRequest)

ListVirtioScsiControllersResponse = _reflection.GeneratedProtocolMessageType('ListVirtioScsiControllersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOSCSICONTROLLERSRESPONSE,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioScsiControllersResponse)
  })
_sym_db.RegisterMessage(ListVirtioScsiControllersResponse)

GetVirtioScsiControllerRequest = _reflection.GeneratedProtocolMessageType('GetVirtioScsiControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTIOSCSICONTROLLERREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetVirtioScsiControllerRequest)
  })
_sym_db.RegisterMessage(GetVirtioScsiControllerRequest)

VirtioScsiControllerStatsRequest = _reflection.GeneratedProtocolMessageType('VirtioScsiControllerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSICONTROLLERSTATSREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiControllerStatsRequest)
  })
_sym_db.RegisterMessage(VirtioScsiControllerStatsRequest)

VirtioScsiControllerStatsResponse = _reflection.GeneratedProtocolMessageType('VirtioScsiControllerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSICONTROLLERSTATSRESPONSE,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiControllerStatsResponse)
  })
_sym_db.RegisterMessage(VirtioScsiControllerStatsResponse)

CreateVirtioScsiLunRequest = _reflection.GeneratedProtocolMessageType('CreateVirtioScsiLunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTIOSCSILUNREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateVirtioScsiLunRequest)
  })
_sym_db.RegisterMessage(CreateVirtioScsiLunRequest)

DeleteVirtioScsiLunRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtioScsiLunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTIOSCSILUNREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteVirtioScsiLunRequest)
  })
_sym_db.RegisterMessage(DeleteVirtioScsiLunRequest)

UpdateVirtioScsiLunRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtioScsiLunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTIOSCSILUNREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateVirtioScsiLunRequest)
  })
_sym_db.RegisterMessage(UpdateVirtioScsiLunRequest)

ListVirtioScsiLunsRequest = _reflection.GeneratedProtocolMessageType('ListVirtioScsiLunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOSCSILUNSREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioScsiLunsRequest)
  })
_sym_db.RegisterMessage(ListVirtioScsiLunsRequest)

ListVirtioScsiLunsResponse = _reflection.GeneratedProtocolMessageType('ListVirtioScsiLunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTIOSCSILUNSRESPONSE,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListVirtioScsiLunsResponse)
  })
_sym_db.RegisterMessage(ListVirtioScsiLunsResponse)

GetVirtioScsiLunRequest = _reflection.GeneratedProtocolMessageType('GetVirtioScsiLunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTIOSCSILUNREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetVirtioScsiLunRequest)
  })
_sym_db.RegisterMessage(GetVirtioScsiLunRequest)

VirtioScsiLunStatsRequest = _reflection.GeneratedProtocolMessageType('VirtioScsiLunStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSILUNSTATSREQUEST,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiLunStatsRequest)
  })
_sym_db.RegisterMessage(VirtioScsiLunStatsRequest)

VirtioScsiLunStatsResponse = _reflection.GeneratedProtocolMessageType('VirtioScsiLunStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTIOSCSILUNSTATSRESPONSE,
  '__module__' : 'frontend_virtio_scsi_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.VirtioScsiLunStatsResponse)
  })
_sym_db.RegisterMessage(VirtioScsiLunStatsResponse)

_FRONTENDVIRTIOSCSISERVICE = DESCRIPTOR.services_by_name['FrontendVirtioScsiService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\027FrontendVirtioScsiProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATEVIRTIOSCSITARGETREQUEST.fields_by_name['parent']._options = None
  _CREATEVIRTIOSCSITARGETREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _CREATEVIRTIOSCSITARGETREQUEST.fields_by_name['virtio_scsi_target']._options = None
  _CREATEVIRTIOSCSITARGETREQUEST.fields_by_name['virtio_scsi_target']._serialized_options = b'\340A\002'
  _DELETEVIRTIOSCSITARGETREQUEST.fields_by_name['name']._options = None
  _DELETEVIRTIOSCSITARGETREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _LISTVIRTIOSCSITARGETSREQUEST.fields_by_name['parent']._options = None
  _LISTVIRTIOSCSITARGETSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _GETVIRTIOSCSITARGETREQUEST.fields_by_name['name']._options = None
  _GETVIRTIOSCSITARGETREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _CREATEVIRTIOSCSICONTROLLERREQUEST.fields_by_name['parent']._options = None
  _CREATEVIRTIOSCSICONTROLLERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _CREATEVIRTIOSCSICONTROLLERREQUEST.fields_by_name['virtio_scsi_controller']._options = None
  _CREATEVIRTIOSCSICONTROLLERREQUEST.fields_by_name['virtio_scsi_controller']._serialized_options = b'\340A\002'
  _DELETEVIRTIOSCSICONTROLLERREQUEST.fields_by_name['name']._options = None
  _DELETEVIRTIOSCSICONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _LISTVIRTIOSCSICONTROLLERSREQUEST.fields_by_name['parent']._options = None
  _LISTVIRTIOSCSICONTROLLERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _GETVIRTIOSCSICONTROLLERREQUEST.fields_by_name['name']._options = None
  _GETVIRTIOSCSICONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _CREATEVIRTIOSCSILUNREQUEST.fields_by_name['parent']._options = None
  _CREATEVIRTIOSCSILUNREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _CREATEVIRTIOSCSILUNREQUEST.fields_by_name['virtio_scsi_lun']._options = None
  _CREATEVIRTIOSCSILUNREQUEST.fields_by_name['virtio_scsi_lun']._serialized_options = b'\340A\002'
  _DELETEVIRTIOSCSILUNREQUEST.fields_by_name['name']._options = None
  _DELETEVIRTIOSCSILUNREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _LISTVIRTIOSCSILUNSREQUEST.fields_by_name['parent']._options = None
  _LISTVIRTIOSCSILUNSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _GETVIRTIOSCSILUNREQUEST.fields_by_name['name']._options = None
  _GETVIRTIOSCSILUNREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['CreateVirtioScsiTarget']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['CreateVirtioScsiTarget']._serialized_options = b'\202\323\344\223\002-\"\027/v1/{parent=subsystems}:\022virtio_scsi_target\332A/parent,virtio_scsi_target,virtio_scsi_target_id'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['DeleteVirtioScsiTarget']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['DeleteVirtioScsiTarget']._serialized_options = b'\202\323\344\223\002**(/v1/{name=subsystems}/{virtioscsitarget}\332A\004name'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['UpdateVirtioScsiTarget']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['UpdateVirtioScsiTarget']._serialized_options = b'\202\323\344\223\002>2(/v1/{virtio_scsi_target.name=subsystems}:\022virtio_scsi_target\332A\036virtio_scsi_target,update_mask'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['ListVirtioScsiTargets']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['ListVirtioScsiTargets']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['GetVirtioScsiTarget']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['GetVirtioScsiTarget']._serialized_options = b'\202\323\344\223\002*\022(/v1/{name=subsystems}/{virtioscsitarget}\332A\004name'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['CreateVirtioScsiController']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['CreateVirtioScsiController']._serialized_options = b'\202\323\344\223\0021\"\027/v1/{parent=subsystems}:\026virtio_scsi_controller\332A7parent,virtio_scsi_controller,virtio_scsi_controller_id'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['DeleteVirtioScsiController']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['DeleteVirtioScsiController']._serialized_options = b'\202\323\344\223\002-*+/v1/{name=virtioscsictrls}/{virtioscsictrl}\332A\004name'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['UpdateVirtioScsiController']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['UpdateVirtioScsiController']._serialized_options = b'\202\323\344\223\002F2,/v1/{virtio_scsi_controller.name=subsystems}:\026virtio_scsi_controller\332A\"virtio_scsi_controller,update_mask'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['ListVirtioScsiControllers']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['ListVirtioScsiControllers']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['GetVirtioScsiController']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['GetVirtioScsiController']._serialized_options = b'\202\323\344\223\002(\022&/v1/{name=subsystems}/{virtioscsictrl}\332A\004name'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['CreateVirtioScsiLun']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['CreateVirtioScsiLun']._serialized_options = b'\202\323\344\223\002*\"\027/v1/{parent=subsystems}:\017virtio_scsi_lun\332A)parent,virtio_scsi_lun,virtio_scsi_lun_id'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['DeleteVirtioScsiLun']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['DeleteVirtioScsiLun']._serialized_options = b'\202\323\344\223\002+*)/v1/{name=virtioscsiluns}/{virtioscsilun}\332A\004name'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['UpdateVirtioScsiLun']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['UpdateVirtioScsiLun']._serialized_options = b'\202\323\344\223\00282%/v1/{virtio_scsi_lun.name=subsystems}:\017virtio_scsi_lun\332A\033virtio_scsi_lun,update_mask'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['ListVirtioScsiLuns']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['ListVirtioScsiLuns']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['GetVirtioScsiLun']._options = None
  _FRONTENDVIRTIOSCSISERVICE.methods_by_name['GetVirtioScsiLun']._serialized_options = b'\202\323\344\223\002\'\022%/v1/{name=subsystems}/{virtioscsilun}\332A\004name'
  _VIRTIOSCSITARGET._serialized_start=263
  _VIRTIOSCSITARGET._serialized_end=341
  _VIRTIOSCSICONTROLLER._serialized_start=343
  _VIRTIOSCSICONTROLLER._serialized_end=457
  _VIRTIOSCSILUN._serialized_start=460
  _VIRTIOSCSILUN._serialized_end=615
  _CREATEVIRTIOSCSITARGETREQUEST._serialized_start=618
  _CREATEVIRTIOSCSITARGETREQUEST._serialized_end=812
  _DELETEVIRTIOSCSITARGETREQUEST._serialized_start=814
  _DELETEVIRTIOSCSITARGETREQUEST._serialized_end=904
  _UPDATEVIRTIOSCSITARGETREQUEST._serialized_start=907
  _UPDATEVIRTIOSCSITARGETREQUEST._serialized_end=1053
  _LISTVIRTIOSCSITARGETSREQUEST._serialized_start=1056
  _LISTVIRTIOSCSITARGETSREQUEST._serialized_end=1186
  _LISTVIRTIOSCSITARGETSRESPONSE._serialized_start=1188
  _LISTVIRTIOSCSITARGETSRESPONSE._serialized_end=1311
  _GETVIRTIOSCSITARGETREQUEST._serialized_start=1313
  _GETVIRTIOSCSITARGETREQUEST._serialized_end=1400
  _VIRTIOSCSITARGETSTATSREQUEST._serialized_start=1402
  _VIRTIOSCSITARGETSTATSREQUEST._serialized_end=1481
  _VIRTIOSCSITARGETSTATSRESPONSE._serialized_start=1483
  _VIRTIOSCSITARGETSTATSRESPONSE._serialized_end=1604
  _CREATEVIRTIOSCSICONTROLLERREQUEST._serialized_start=1607
  _CREATEVIRTIOSCSICONTROLLERREQUEST._serialized_end=1821
  _DELETEVIRTIOSCSICONTROLLERREQUEST._serialized_start=1823
  _DELETEVIRTIOSCSICONTROLLERREQUEST._serialized_end=1921
  _UPDATEVIRTIOSCSICONTROLLERREQUEST._serialized_start=1924
  _UPDATEVIRTIOSCSICONTROLLERREQUEST._serialized_end=2082
  _LISTVIRTIOSCSICONTROLLERSREQUEST._serialized_start=2085
  _LISTVIRTIOSCSICONTROLLERSREQUEST._serialized_end=2223
  _LISTVIRTIOSCSICONTROLLERSRESPONSE._serialized_start=2226
  _LISTVIRTIOSCSICONTROLLERSRESPONSE._serialized_end=2361
  _GETVIRTIOSCSICONTROLLERREQUEST._serialized_start=2363
  _GETVIRTIOSCSICONTROLLERREQUEST._serialized_end=2458
  _VIRTIOSCSICONTROLLERSTATSREQUEST._serialized_start=2460
  _VIRTIOSCSICONTROLLERSTATSREQUEST._serialized_end=2547
  _VIRTIOSCSICONTROLLERSTATSRESPONSE._serialized_start=2549
  _VIRTIOSCSICONTROLLERSTATSRESPONSE._serialized_end=2674
  _CREATEVIRTIOSCSILUNREQUEST._serialized_start=2677
  _CREATEVIRTIOSCSILUNREQUEST._serialized_end=2856
  _DELETEVIRTIOSCSILUNREQUEST._serialized_start=2858
  _DELETEVIRTIOSCSILUNREQUEST._serialized_end=2942
  _UPDATEVIRTIOSCSILUNREQUEST._serialized_start=2945
  _UPDATEVIRTIOSCSILUNREQUEST._serialized_end=3082
  _LISTVIRTIOSCSILUNSREQUEST._serialized_start=3084
  _LISTVIRTIOSCSILUNSREQUEST._serialized_end=3208
  _LISTVIRTIOSCSILUNSRESPONSE._serialized_start=3210
  _LISTVIRTIOSCSILUNSRESPONSE._serialized_end=3324
  _GETVIRTIOSCSILUNREQUEST._serialized_start=3326
  _GETVIRTIOSCSILUNREQUEST._serialized_end=3407
  _VIRTIOSCSILUNSTATSREQUEST._serialized_start=3409
  _VIRTIOSCSILUNSTATSREQUEST._serialized_end=3535
  _VIRTIOSCSILUNSTATSRESPONSE._serialized_start=3537
  _VIRTIOSCSILUNSTATSRESPONSE._serialized_end=3655
  _FRONTENDVIRTIOSCSISERVICE._serialized_start=3658
  _FRONTENDVIRTIOSCSISERVICE._serialized_end=6891
# @@protoc_insertion_point(module_scope)
